## Campbell V., Legendre P., Lapointe F.-J. 2011. The
## performance of the Congruence Among Distance Matrices (CADM) test
## in phylogenetic analysis. BMC Evolutionary Biology. 11: 64.

library(phangorn)
library(shipunov)

options(scipen=100)

conc <- read.dna("data/oi.fasta", format="fasta")

## its     all chars  689  potentially taxonomically informative chars  399
## rbcl    all chars  589  potentially taxonomically informative chars  75
## trnl    all chars  1303 potentially taxonomically informative chars  302
its <- conc[, 1:689]
cp2 <- conc[, -(1:689)]

its.phydat <- phyDat(its)
cp2.phydat <- phyDat(cp2)

its.nj <- NJ(dist.hamming(its.phydat))
cp2.nj <- NJ(dist.hamming(cp2.phydat))

# ===

ITSNJ <- cophenetic(its.nj)
CP2NJ <- cophenetic(cp2.nj)
CADM.global(rbind(ITSNJ, CP2NJ), nmat=2, n=nrow(ITSNJ), nperm=10000)

# ===

its.pr <- optim.parsimony(its.nj, its.phydat)
cp2.pr <- optim.parsimony(cp2.nj, cp2.phydat)
ITS <- cophenetic(its.pr)
CP2 <- cophenetic(cp2.pr)
CADM.global(rbind(ITS, CP2), nmat=2, n=nrow(ITS), nperm=10000)
