library(ape)
library(svglite)
library(shipunov)

Make.treesc <- function(treelist) {
## LABELS
tl <- lapply(treelist, `[[`, "tip.label")
## remove ids
tl <- lapply(tl, function(.x) sub("__.*$", "", .x))
## remove triple names
tl <- lapply(tl, function(.x) gsub("^([^_]*_[^_]*)_.*$", "\\1", .x))
## restore species names
tl <- lapply(tl, make.unique)
## make unique to prepare for duplicates removal
tl <- lapply(tl, function(.x) gsub("_", " ", .x))
## return changed labels back to trees
for (n in 1:length(treelist)) treelist[[n]]$tip.label <- tl[[n]]
## TREES
## drop duplicates
treelist <- lapply(treelist, function(.x) ape::drop.tip(.x, .x$tip.label[grepl("\\.[1-9]", .x$tip.label)]))
## drop " sp." tips
treelist <- lapply(treelist, function(.x) ape::drop.tip(.x, .x$tip.label[grepl(" sp\\.", .x$tip.label)]))
## what is in all
allt <- table(unlist(lapply(treelist, `[[`, "tip.label")))
all <- names(allt)[allt == length(treelist)]
## drop what is not in all
lapply(treelist, function(.x) ape::drop.tip(.x, .x$tip.label[!.x$tip.label %in% all]))
}

## classification table
cl <- read.table("data/buxineae_treecl_classif.txt", sep="\t", quote="", as.is=TRUE)

DIR <-  dir("data")
trees <- c("oi_mb", "oi_raxml", "cp_mb", "cp_raxml")
for(t in trees) assign(t, read.tree(paste0("data/",  DIR[grepl(t, DIR)])))

oi_rx <- Make.treesc(list(oi_raxml))[[1]]
oi_rx <- drop.tip(oi_rx, c("Trochodendron aralioides", "Tetracentron sinense"))
oi_rx$tip.label[oi_rx$tip.label == "Didymeles madagascariensis"] <- "Didymeles madagasc." # to fit better
oi_rx <- rotate(oi_rx, getMRCA(oi_rx, c("Haptanthus hazlettii", "Didymeles madagasc.")))
oi_rx <- rotate(oi_rx, getMRCA(oi_rx, c("Haptanthus hazlettii", "Sarcococca conzattii")))
oi_rx <- rotate(oi_rx, getMRCA(oi_rx, c("Buxus balearica", "Buxus mexicana")))
oi_rx <- rotate(oi_rx, getMRCA(oi_rx, c("Buxus natalensis", "Buxus mexicana")))
#
oi_mb <- Make.treesc(list(oi_mb))[[1]]
oi_mb <- drop.tip(oi_mb, c("Trochodendron aralioides", "Tetracentron sinense"))
oi_mb$tip.label[oi_mb$tip.label == "Didymeles madagascariensis"] <- "Didymeles madagasc." # to fit better
oi_mb <- rotate(oi_mb, getMRCA(oi_mb, c("Haptanthus hazlettii", "Sarcococca conzattii")))
oi_mb <- rotate(oi_mb, getMRCA(oi_mb, c("Sarcococca confusa", "Sarcococca conzattii")))
oi_mb <- rotate(oi_mb, getMRCA(oi_mb, c("Pachysandra terminalis", "Styloceras laurifolium")))
svglite("data/oi_rx_mb_phylocl.svg", width=8)
cl <- cl[cl[, 1] %in% oi_rx$tip.label, ]
par(mfrow=c(1, 2))
Plot.phylocl(oi_rx, cl, strict=FALSE, no.margin=TRUE, ct.off=0.4, cex=0.6)
Plot.phylocl(oi_mb, cl, strict=FALSE, no.margin=TRUE, ct.off=0.4, cex=0.6)
dev.off()

cp_rx <- Make.treesc(list(cp_raxml))[[1]]
cp_rx <- drop.tip(cp_rx, c("Trochodendron aralioides", "Tetracentron sinense"))
cp_rx <- rotate(cp_rx, getMRCA(cp_rx, c("Haptanthus hazlettii", "Didymeles perrieri")))
cp_rx <- rotate(cp_rx, getMRCA(cp_rx, c("Sarcococca conzattii", "Buxus balearica")))
cp_rx <- rotate(cp_rx, getMRCA(cp_rx, c("Sarcococca conzattii", "Sarcococca hookeriana")))
cp_rx <- rotate(cp_rx, getMRCA(cp_rx, c("Styloceras laurifolium", "Pachysandra terminalis")))
cp_rx <- rotate(cp_rx, getMRCA(cp_rx, c("Buxus mexicana", "Buxus balearica")))
#
cp_mb <- Make.treesc(list(cp_mb))[[1]]
cp_mb <- drop.tip(cp_mb, c("Trochodendron aralioides", "Tetracentron sinense"))
cp_mb <- rotate(cp_mb, getMRCA(cp_mb, c("Didymeles perrieri", "Sarcococca conzattii")))
cp_mb <- rotate(cp_mb, getMRCA(cp_mb, c("Styloceras laurifolium", "Pachysandra terminalis")))
svglite("data/cp_rx_mb_phylocl.svg", width=8, height=5.5)
cl <- cl[cl[, 1] %in% cp_rx$tip.label, ]
par(mfrow=c(1, 2))
Plot.phylocl(cp_rx, cl, strict=FALSE, no.margin=TRUE, ct.off=0.4, cex=0.6)
Plot.phylocl(cp_mb, cl, strict=FALSE, no.margin=TRUE, ct.off=0.4, cex=0.6)
dev.off()
