library(ape)
library(phytools)
library(svglite)

Clean.tree.names <- function(tree) {
## LABELS
tl <- tree$tip.label
## remove sequence ids (everything after double underscore: Ripeline convention)
tl <- sub("__.*$", "", tl)
## remove triple names (so no subspecies etc.) but do not reduce "sp." names and do not touch names with initial "_" (saved triplets)
tl <- gsub("^([^_]+_[^_][^.]+)_.*$", "\\1", tl)
## remove saved triplets mark
tl <- gsub("^_", "", tl)
## restore binomials (remove underscore between genus name and species epithet: ape convention)
tl <- gsub("_", " ", tl)
## Buxaceae-specific
tl <- gsub('Buxus rotundifolia', 'Buxus "rotundifolia"', tl)
tl <- gsub('Buxus sp. celebica', 'Buxus "celebica"', tl)
## label duplicates with numbers
tl <- make.unique(tl)
## return changed labels back to trees
tree$tip.label <- tl
## drop duplicates, leave only the first one
tree <- drop.tip(tree, tree$tip.label[grepl("\\.[1-9]", tree$tip.label)])
## drop " sp." tips
## tree <- drop.tip(tree, tree$tip.label[grepl(" sp\\.", tree$tip.label)])
return(tree)
}

## which species are "ours"
ours <- scan("data/our_species.txt", sep="\t", what="char")
ours <- c(ours, "Buxus cephalantha") # because it presents as a triplet
ours <- c(ours, 'Buxus "celebica"') # because it is in quotes

Tree2svg <- function(tree, ...){
svglite(paste0("data/", deparse(substitute(tree)), ".svg"), ...)
par(mar=rep(0, 4))
print(tree$tip.label[tree$tip.label %in% ours]) # to control "our" species
tree$tip.label[tree$tip.label %in% ours] <- paste0(tree$tip.label[tree$tip.label %in% ours], "*")
plot(tree, no.margin=TRUE, cex=0.95)
tree$node.label[tree$node.label == "NA"] <- ""
tree$node.label[as.numeric(tree$node.label) <= 60] <- ""
nodelabels(tree$node.label, frame="none", bg="transparent", adj=-0.1, cex=0.8)
add.scale.bar()
Add.labels()
dev.off()
}

cpmb <- Clean.tree.names(read.tree("data/20200224_080938_buxineae_cp_mb.tre"))
cpmb$edge.length <- cpmb$edge.length + 0.005
Add.labels <- function() {
cladelabels(text="Eurasian clade", node=getMRCA(cpmb, c("Buxus papillosa", "Buxus balearica")), offset=13)
cladelabels(text="African clade", node=getMRCA(cpmb, c("Buxus natalensis", "Buxus benguellensis")), offset=12)
cladelabels(text="American clade", node=getMRCA(cpmb, c("Buxus mexicana", "Buxus acuminata")), offset=11)
cladelabels(text="Pachysandroideae", node=getMRCA(cpmb, c("Sarcococca hookeriana", "Pachysandra axillaris")), offset=15.8)
cladelabels(text="Outgroups", node=getMRCA(cpmb, c("Trochodendron aralioides", "Tetracentron sinense")), offset=14, orientation="horizontal")
}
cpmb <- rotate(cpmb, getMRCA(cpmb, c("Haptanthus hazlettii", "Tetracentron sinense")))
Tree2svg(cpmb, height=16, width=10.5)

oimb <- Clean.tree.names(read.tree("data/20200224_114406_buxineae_oi_mb.tre"))
oimb$edge.length <- oimb$edge.length + 0.005
oimb <- rotate(oimb, getMRCA(oimb, c("Haptanthus hazlettii", "Tetracentron sinense")))
Add.labels <- function() {
cladelabels(text="Eurasian clade", node=getMRCA(oimb, c("Buxus sp. Philippines", "Buxus austroyunnanensis")), offset=12)
cladelabels(text="African clade", node=getMRCA(oimb, c("Buxus itremoensis", "Buxus acutata")), offset=12)
cladelabels(text="American clade", node=getMRCA(oimb, c("Buxus jaucoensis", "Buxus acuminata")), offset=11)
cladelabels(text="Pachysandroideae", node=getMRCA(oimb, c("Sarcococca conzattii", "Pachysandra axillaris")), offset=16)
cladelabels(text="Outgroups", node=getMRCA(oimb, c("Trochodendron aralioides", "Tetracentron sinense")), offset=16, orientation="horizontal")
}
Tree2svg(oimb, height=20, width=12)

fiml <- Clean.tree.names(read.tree("data/20200313_215831_its_full_raxml_buxineae.tre"))
fiml$edge.length <- fiml$edge.length + 0.012
Add.labels <- function() {
}
Tree2svg(fiml)

