library(phangorn)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")
treesp <- read.table("../../data/buxineae_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup"]
outgroups <- gsub(" ", "_", outgroups)

outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier"]
outliers <- gsub(" ", "_", outliers)

conc <- read.dna("40_concatenated/cp.fasta", format="fasta")
LAB <- sub("__.*$", "", labels(conc))
OUT <- labels(conc)[LAB %in% outgroups]
EXC <- labels(conc)[LAB %in% outliers] # is not used

conc.phydat <- phyDat(conc)

conc.pr <- pratchet(conc.phydat, maxit=2000, k=20)
conc.pr <- acctran(conc.pr, conc.phydat)
conc.ptrees <- bootstrap.phyDat(conc.phydat, pratchet, bs=1000, multicore=T)
conc.prr <- Root1(conc.pr, OUT, resolve.root=T)
##
pdf(paste("99_mp_mb_trees/", DATE, "_buxineae_cp_mp_boot_tree.pdf", sep=""), height=24, width=24)
oldpar <- par(mar=c(0,0,0,0))
conc.prr.b <- plotBS(conc.prr, conc.ptrees, p=50, type="phylogram") # to improve edge length, change/plot "conc.prr.b"
mtext("cp rbcl + trnl + matk + petd MP", font=2, line=-3)
add.scale.bar()
par(oldpar)
dev.off()
##
conc.prr.b$node.label[conc.prr.b$node.label == "NA"] <- ""
write.tree(conc.prr.b, file=paste("99_mp_mb_trees/", DATE, "_buxineae_cp_mp_boot_tree.tre", sep=""))
