library(phangorn)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")
treesp <- read.table("../../data/buxineae_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup"]
outgroups <- gsub(" ", "_", outgroups)

outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier"]
outliers <- gsub(" ", "_", outliers)

conc <- read.dna("40_concatenated/oi.fasta", format="fasta")
LAB <- sub("__.*$", "", labels(conc))
OUT <- labels(conc)[LAB %in% outgroups]

EXC <- labels(conc)[LAB %in% outliers] # used!
conc <- conc[!labels(conc) %in% EXC, ] # remove outliers

conc.phydat <- phyDat(conc)

tr1 <- NJ(dist.hamming(conc.phydat))
conc.pr <- pratchet(conc.phydat, maxit=2000, minit=100, k=100, start=tr1) # changed 20200224
if (!is.binary(conc.pr)) conc.pr <- multi2di(conc.pr) # changed 20200224
conc.pr <- acctran(conc.pr, conc.phydat)
conc.ptrees <- bootstrap.phyDat(conc.phydat, pratchet, bs=1000, multicore=T)
conc.prr <- Root1(conc.pr, OUT, resolve.root=T)
##
pdf(paste("99_mp_mb_trees/", DATE, "_buxineae_oi_mp_boot_tree.pdf", sep=""), height=36, width=18)
oldpar <- par(mar=c(0,0,0,0))
conc.prr.b <- plotBS(conc.prr, conc.ptrees, p=50, type="phylogram") # to improve edge length, change/plot "conc.prr.b"
add.scale.bar()
mtext("oi its + rbcl + trnl MP", font=2, line=-3)
par(oldpar)
dev.off()
##
conc.prr.b$node.label[conc.prr.b$node.label == "NA"] <- ""
write.tree(conc.prr.b, file=paste("99_mp_mb_trees/", DATE, "_buxineae_oi_mp_boot_tree.tre", sep=""))
