library(ips)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")
treesp <- read.table("../../data/buxineae_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup"]
outgroups <- gsub(" ", "_", outgroups)

outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier"]
outliers <- gsub(" ", "_", outliers)

conc <- read.dna("40_concatenated/cp.fasta", format="fasta")
LAB <- sub("__.*$", "", labels(conc))
OUT <- labels(conc)[LAB %in% outgroups]
EXC <- labels(conc)[LAB %in% outliers] # is not used

setwd("70_mrbayes_working")
tr <- MrBayes(conc, file="cp", burnin=5000, run=T)
## tr <- read.nexus("conc.tre")
setwd("..")

tr <- tr[[1]]
tr <- root(tr, outgroup=OUT, resolve.root=T)
tr$node.label <- suppressWarnings(round(as.numeric(tr$node.label)*100)) # warning is OK

pdf(paste("99_mp_mb_trees/", DATE, "_buxineae_cp_mb_tree.pdf", sep=""), height=24, width=24)
oldpar <- par(mar=c(0,0,0,0))
plot(tr)
nodelabels(tr$node.label, frame="none", bg="transparent", adj=-0.1)
mtext("cp rbcl + trnl + matk + petd MB", font=2, line=-3)
add.scale.bar()
dev.off()
#
tr$node.label[tr$node.label == "NA"] <- ""
write.tree(tr, file=paste("99_mp_mb_trees/", DATE, "_buxineae_cp_mb.tre", sep=""))
